==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/admin/stats/server_info.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	server_info.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'HEADING_SUB_TITLE' => 'Hilfsprogramme',
	'HEADING_TITLE' => 'Server Informationen',
	'SEND_SERVER_INFO_COMMENT_LABEL' => 'Kommentar:',
	'SEND_SERVER_INFO_ERROR' => 'Die Daten konnten leider nicht versendet werden.',
	'SEND_SERVER_INFO_MESSAGE_LABEL' => 'Nachricht:',
	'SEND_SERVER_INFO_SEND_TEXT' => 'Mit Klick auf "Senden" werden ausschließlich die in diesem Formular stehenden Daten einmalig an die Gambio GmbH gesendet.',
	'SEND_SERVER_INFO_SUCCESS' => 'Vielen Dank! Die Daten wurden erfolgreich an die Gambio GmbH gesendet.',
	'SEND_SERVER_INFO_TEXT' => 'Sie können uns bei der Weiterentwicklung der Gambio-Shopsoftware unterstützen, indem Sie uns Ihre Server-Informationen zusenden.<br />Da Serverkonfigurationen stark voneinander abweichen, helfen uns diese Informationen serverspezifische Konflikte zu vermeiden und somit ein sichereres und stabileres System anbieten können.',
	'SEND_SERVER_INFO_TITLE' => 'Unterstützen Sie uns bei der Weiterentwicklung!',
	'TITLE_DATABASE' => 'Datenbank:',
	'TITLE_DATABASE_DATE' => 'Datenbank Datum:',
	'TITLE_DATABASE_HOST' => 'Datenbank Host:',
	'TITLE_HTTP_SERVER' => 'HTTP Server:',
	'TITLE_PHP_VERSION' => 'PHP Version:',
	'TITLE_SERVER_DATE' => 'Server Datum:',
	'TITLE_SERVER_HOST' => 'Server Host:',
	'TITLE_SERVER_OS' => 'Server OS:',
	'TITLE_SERVER_UP_TIME' => 'Server Up Time:',
	'TITLE_ZEND_VERSION' => 'Zend:'
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/stats/server_info.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	server_info.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'HEADING_SUB_TITLE' => 'Hilfsprogramme',
	'HEADING_TITLE' => 'Server Informationen',
	'SEND_SERVER_INFO_COMMENT_LABEL' => 'Kommentar:',
	'SEND_SERVER_INFO_ERROR' => 'Die Daten konnten leider nicht versendet werden.',
	'SEND_SERVER_INFO_MESSAGE_LABEL' => 'Nachricht:',
	'SEND_SERVER_INFO_SEND_TEXT' => 'Mit Klick auf "Senden" werden ausschließlich die in diesem Formular stehenden Daten einmalig an die Gambio GmbH gesendet.',
	'SEND_SERVER_INFO_SUCCESS' => 'Vielen Dank! Die Daten wurden erfolgreich an die Gambio GmbH gesendet.',
	'SEND_SERVER_INFO_TEXT' => 'Du kannst uns bei der Weiterentwicklung der Gambio-Shopsoftware unterstützen, indem du uns deine Server-Informationen zusendest.<br />Da Serverkonfigurationen stark voneinander abweichen, helfen uns diese Informationen serverspezifische Konflikte zu vermeiden und somit ein sichereres und stabileres System anbieten können.',
	'SEND_SERVER_INFO_TITLE' => 'Unterstütze uns bei der Weiterentwicklung!',
	'TITLE_DATABASE' => 'Datenbank:',
	'TITLE_DATABASE_DATE' => 'Datenbank Datum:',
	'TITLE_DATABASE_HOST' => 'Datenbank Host:',
	'TITLE_HTTP_SERVER' => 'HTTP Server:',
	'TITLE_PHP_VERSION' => 'PHP Version:',
	'TITLE_SERVER_DATE' => 'Server Datum:',
	'TITLE_SERVER_HOST' => 'Server Host:',
	'TITLE_SERVER_OS' => 'Server OS:',
	'TITLE_SERVER_UP_TIME' => 'Server Up Time:',
	'TITLE_ZEND_VERSION' => 'Zend:'
);
